@@ -6,29 +6,27 @@
 //
 //===----------------------------------------------------------------------===//
 
-// Can't test the system lib because this test enables debug mode
-// UNSUPPORTED: with_system_cxx_lib
-
 // <list>
 
 // void splice(const_iterator position, list& x, iterator first, iterator last);
 
-#define _LIBCPP_DEBUG 1
-#define _LIBCPP_ASSERT(x, m) ((x) ? (void)0 : std::exit(0))
+// UNSUPPORTED: libcxx-no-debug-mode
+
+// ADDITIONAL_COMPILE_FLAGS: -D_LIBCPP_DEBUG=1
 
 #include <list>
-#include <cstdlib>
-#include <cassert>
 
 #include "test_macros.h"
+#include "debug_macros.h"
 
 int main(int, char**)
 {
     {
-        std::list<int> v1(3);
-        std::list<int> v2(3);
-        v1.splice(v1.begin(), v2, v2.begin(), v1.end());
-        assert(false);
+      std::list<int> v1(3);
+      std::list<int> v2(3);
+      TEST_LIBCPP_ASSERT_FAILURE(
+          v1.splice(v1.begin(), v2, v2.begin(), v1.end()),
+          "list::splice(iterator, list, iterator, iterator) called with third iterator not referring to the list argument");
     }
 
   return 0;
