@@ -13,12 +13,11 @@
 // map& operator=(const map& m);
 
 #include <map>
-#include <cassert>
-#include <vector>
 #include <algorithm>
+#include <cassert>
+#include <cstdio>
 #include <iterator>
-
-#include <iostream>
+#include <vector>
 
 #include "test_macros.h"
 #include "../../../test_compare.h"
@@ -41,12 +40,12 @@ public:
     template <class U> bool operator==(const counting_allocatorT<U>& other) const noexcept { return foo == other.foo; }
     template <class U> bool operator!=(const counting_allocatorT<U>& other) const noexcept { return foo != other.foo; }
 
-    T * allocate(const size_t n) const {
+    T* allocate(size_t n) const {
         ca_allocs.push_back(foo);
         void * const pv = ::malloc(n * sizeof(T));
         return static_cast<T *>(pv);
     }
-    void deallocate(T * const p, size_t) const noexcept {
+    void deallocate(T* p, size_t) const noexcept {
         ca_deallocs.push_back(foo);
         free(p);
     }
@@ -64,12 +63,12 @@ public:
     template <class U> bool operator==(const counting_allocatorF<U>& other) const noexcept { return foo == other.foo; }
     template <class U> bool operator!=(const counting_allocatorF<U>& other) const noexcept { return foo != other.foo; }
 
-    T * allocate(const size_t n) const {
+    T* allocate(size_t n) const {
         ca_allocs.push_back(foo);
         void * const pv = ::malloc(n * sizeof(T));
         return static_cast<T *>(pv);
     }
-    void deallocate(T * const p, size_t) const noexcept {
+    void deallocate(T* p, size_t) const noexcept {
         ca_deallocs.push_back(foo);
         free(p);
     }
@@ -78,7 +77,8 @@ public:
 bool balanced_allocs() {
     std::vector<int> temp1, temp2;
 
-    std::cout << "Allocations = " << ca_allocs.size() << ", deallocatons = " << ca_deallocs.size() << std::endl;
+    std::printf("Allocations = %zu, deallocations = %zu\n", ca_allocs.size(),
+                ca_deallocs.size());
     if (ca_allocs.size() != ca_deallocs.size())
         return false;
 
@@ -86,27 +86,32 @@ bool balanced_allocs() {
     std::sort(temp1.begin(), temp1.end());
     temp2.clear();
     std::unique_copy(temp1.begin(), temp1.end(), std::back_inserter<std::vector<int>>(temp2));
-    std::cout << "There were " << temp2.size() << " different allocators\n";
+    std::printf("There were %zu different allocators\n", temp2.size());
 
     for (std::vector<int>::const_iterator it = temp2.begin(); it != temp2.end(); ++it ) {
-        std::cout << *it << ": " << std::count(ca_allocs.begin(), ca_allocs.end(), *it) << " vs " << std::count(ca_deallocs.begin(), ca_deallocs.end(), *it) << std::endl;
-        if ( std::count(ca_allocs.begin(), ca_allocs.end(), *it) != std::count(ca_deallocs.begin(), ca_deallocs.end(), *it))
+        std::ptrdiff_t const allocs = std::count(ca_allocs.begin(), ca_allocs.end(), *it);
+        std::ptrdiff_t const deallocs = std::count(ca_deallocs.begin(), ca_deallocs.end(), *it);
+        std::printf("%d: %td vs %td\n", *it, allocs, deallocs);
+        if (allocs != deallocs)
             return false;
-        }
+    }
 
     temp1 = ca_allocs;
     std::sort(temp1.begin(), temp1.end());
     temp2.clear();
     std::unique_copy(temp1.begin(), temp1.end(), std::back_inserter<std::vector<int>>(temp2));
-    std::cout << "There were " << temp2.size() << " different (de)allocators\n";
+    std::printf("There were %zu different (de)allocators\n", temp2.size());
+
     for (std::vector<int>::const_iterator it = ca_deallocs.begin(); it != ca_deallocs.end(); ++it ) {
-        std::cout << *it << ": " << std::count(ca_allocs.begin(), ca_allocs.end(), *it) << " vs " << std::count(ca_deallocs.begin(), ca_deallocs.end(), *it) << std::endl;
-        if ( std::count(ca_allocs.begin(), ca_allocs.end(), *it) != std::count(ca_deallocs.begin(), ca_deallocs.end(), *it))
+        std::ptrdiff_t const allocs = std::count(ca_allocs.begin(), ca_allocs.end(), *it);
+        std::ptrdiff_t const deallocs = std::count(ca_deallocs.begin(), ca_deallocs.end(), *it);
+        std::printf("%d: %td vs %td\n", *it, allocs, deallocs);
+        if (allocs != deallocs)
             return false;
-        }
+    }
 
     return true;
-    }
+}
 #endif
 
 int main(int, char**)
@@ -125,7 +130,7 @@ int main(int, char**)
             V(3, 1.5),
             V(3, 2)
         };
-        typedef test_compare<std::less<int> > C;
+        typedef test_less<int> C;
         typedef test_allocator<V> A;
         std::map<int, double, C, A> mo(ar, ar+sizeof(ar)/sizeof(ar[0]), C(5), A(2));
         std::map<int, double, C, A> m(ar, ar+sizeof(ar)/sizeof(ar[0])/2, C(3), A(7));
@@ -175,7 +180,7 @@ int main(int, char**)
             V(3, 1.5),
             V(3, 2)
         };
-        typedef test_compare<std::less<int> > C;
+        typedef test_less<int> C;
         typedef other_allocator<V> A;
         std::map<int, double, C, A> mo(ar, ar+sizeof(ar)/sizeof(ar[0]), C(5), A(2));
         std::map<int, double, C, A> m(ar, ar+sizeof(ar)/sizeof(ar[0])/2, C(3), A(7));
@@ -211,7 +216,7 @@ int main(int, char**)
             V(3, 1.5),
             V(3, 2)
         };
-        typedef test_compare<std::less<int> > C;
+        typedef test_less<int> C;
         typedef min_allocator<V> A;
         std::map<int, double, C, A> mo(ar, ar+sizeof(ar)/sizeof(ar[0]), C(5), A());
         std::map<int, double, C, A> m(ar, ar+sizeof(ar)/sizeof(ar[0])/2, C(3), A());
@@ -246,7 +251,7 @@ int main(int, char**)
             V(3, 1.5),
             V(3, 2)
         };
-        typedef test_compare<std::less<int> > C;
+        typedef test_less<int> C;
         typedef min_allocator<V> A;
         std::map<int, double, C, A> mo(ar, ar+sizeof(ar)/sizeof(ar[0]), C(5), A());
         std::map<int, double, C, A> m(ar, ar+sizeof(ar)/sizeof(ar[0])/2, C(3), A());
@@ -283,7 +288,7 @@ int main(int, char**)
             V(3, 1.5),
             V(3, 2)
         };
-        typedef test_compare<std::less<int> > C;
+        typedef test_less<int> C;
         typedef counting_allocatorT<V> A;
         std::map<int, double, C, A> mo(ar, ar+sizeof(ar)/sizeof(ar[0]), C(5), A(1));
         std::map<int, double, C, A> m(ar, ar+sizeof(ar)/sizeof(ar[0])/2, C(3), A(2));
@@ -317,7 +322,7 @@ int main(int, char**)
             V(3, 1.5),
             V(3, 2)
         };
-        typedef test_compare<std::less<int> > C;
+        typedef test_less<int> C;
         typedef counting_allocatorF<V> A;
         std::map<int, double, C, A> mo(ar, ar+sizeof(ar)/sizeof(ar[0]), C(5), A(100));
         std::map<int, double, C, A> m(ar, ar+sizeof(ar)/sizeof(ar[0])/2, C(3), A(200));
