@@ -1,9 +1,8 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 #ifndef MAP_ALLOCATOR_REQUIREMENT_TEST_TEMPLATES_H
@@ -19,14 +18,13 @@
 // emplace(...);
 // emplace_hint(...);
 
-// UNSUPPORTED: c++98, c++03
+// UNSUPPORTED: c++03
 
 #include <cassert>
 
 #include "test_macros.h"
-#include "count_new.hpp"
+#include "count_new.h"
 #include "container_test_types.h"
-#include "assert_checkpoint.h"
 
 
 template <class Container>
@@ -36,7 +34,7 @@ void testMapInsert()
   ConstructController* cc = getConstructController();
   cc->reset();
   {
-    CHECKPOINT("Testing C::insert(const value_type&)");
+    // Testing C::insert(const value_type&)
     Container c;
     const ValueTp v(42, 1);
     cc->expect<const ValueTp&>();
@@ -49,7 +47,7 @@ void testMapInsert()
     }
   }
   {
-    CHECKPOINT("Testing C::insert(value_type&)");
+    // Testing C::insert(value_type&)
     Container c;
     ValueTp v(42, 1);
     cc->expect<const ValueTp&>();
@@ -62,7 +60,7 @@ void testMapInsert()
     }
   }
   {
-    CHECKPOINT("Testing C::insert(value_type&&)");
+    // Testing C::insert(value_type&&)
     Container c;
     ValueTp v(42, 1);
     cc->expect<ValueTp&&>();
@@ -75,7 +73,7 @@ void testMapInsert()
     }
   }
   {
-    CHECKPOINT("Testing C::insert(const value_type&&)");
+    // Testing C::insert(const value_type&&)
     Container c;
     const ValueTp v(42, 1);
     cc->expect<const ValueTp&>();
@@ -88,7 +86,7 @@ void testMapInsert()
     }
   }
   {
-    CHECKPOINT("Testing C::insert({key, value})");
+    // Testing C::insert({key, value})
     Container c;
     cc->expect<ValueTp&&>();
     assert(c.insert({42, 1}).second);
@@ -100,7 +98,7 @@ void testMapInsert()
     }
   }
   {
-    CHECKPOINT("Testing C::insert(std::initializer_list<ValueTp>)");
+    // Testing C::insert(std::initializer_list<ValueTp>)
     Container c;
     std::initializer_list<ValueTp> il = { ValueTp(1, 1), ValueTp(2, 1) };
     cc->expect<ValueTp const&>(2);
@@ -112,7 +110,7 @@ void testMapInsert()
     }
   }
   {
-    CHECKPOINT("Testing C::insert(Iter, Iter) for *Iter = value_type const&");
+    // Testing C::insert(Iter, Iter) for *Iter = value_type const&
     Container c;
     const ValueTp ValueList[] = { ValueTp(1, 1), ValueTp(2, 1), ValueTp(3, 1) };
     cc->expect<ValueTp const&>(3);
@@ -124,7 +122,7 @@ void testMapInsert()
     }
   }
   {
-    CHECKPOINT("Testing C::insert(Iter, Iter) for *Iter = value_type&&");
+    // Testing C::insert(Iter, Iter) for *Iter = value_type&&
     Container c;
     ValueTp ValueList[] = { ValueTp(1, 1), ValueTp(2, 1) , ValueTp(3, 1) };
     cc->expect<ValueTp&&>(3);
@@ -139,7 +137,7 @@ void testMapInsert()
     }
   }
   {
-    CHECKPOINT("Testing C::insert(Iter, Iter) for *Iter = value_type&");
+    // Testing C::insert(Iter, Iter) for *Iter = value_type&
     Container c;
     ValueTp ValueList[] = { ValueTp(1, 1), ValueTp(2, 1) , ValueTp(3, 1) };
     cc->expect<ValueTp const&>(3);
@@ -165,7 +163,7 @@ void testMapInsertHint()
   ConstructController* cc = getConstructController();
   cc->reset();
   {
-    CHECKPOINT("Testing C::insert(p, const value_type&)");
+    // Testing C::insert(p, const value_type&)
     Container c;
     const ValueTp v(42, 1);
     cc->expect<const ValueTp&>();
@@ -182,7 +180,7 @@ void testMapInsertHint()
     }
   }
   {
-    CHECKPOINT("Testing C::insert(p, value_type&)");
+    // Testing C::insert(p, value_type&)
     Container c;
     ValueTp v(42, 1);
     cc->expect<ValueTp const&>();
@@ -199,7 +197,7 @@ void testMapInsertHint()
     }
   }
   {
-    CHECKPOINT("Testing C::insert(p, value_type&&)");
+    // Testing C::insert(p, value_type&&)
     Container c;
     ValueTp v(42, 1);
     cc->expect<ValueTp&&>();
@@ -216,7 +214,7 @@ void testMapInsertHint()
     }
   }
   {
-    CHECKPOINT("Testing C::insert(p, {key, value})");
+    // Testing C::insert(p, {key, value})
     Container c;
     cc->expect<ValueTp&&>();
     It ret = c.insert(c.end(), {42, 1});
@@ -231,7 +229,7 @@ void testMapInsertHint()
     }
   }
   {
-    CHECKPOINT("Testing C::insert(p, const value_type&&)");
+    // Testing C::insert(p, const value_type&&)
     Container c;
     const ValueTp v(42, 1);
     cc->expect<const ValueTp&>();
@@ -248,7 +246,7 @@ void testMapInsertHint()
     }
   }
   {
-    CHECKPOINT("Testing C::insert(p, pair<Key, Mapped> const&)");
+    // Testing C::insert(p, pair<Key, Mapped> const&)
     Container c;
     const NonConstKeyPair v(42, 1);
     cc->expect<const NonConstKeyPair&>();
@@ -265,7 +263,7 @@ void testMapInsertHint()
     }
   }
   {
-    CHECKPOINT("Testing C::insert(p, pair<Key, Mapped>&&)");
+    // Testing C::insert(p, pair<Key, Mapped>&&)
     Container c;
     NonConstKeyPair v(42, 1);
     cc->expect<NonConstKeyPair&&>();
@@ -296,7 +294,7 @@ void testMapEmplace()
   ConstructController* cc = getConstructController();
   cc->reset();
   {
-    CHECKPOINT("Testing C::emplace(const value_type&)");
+    // Testing C::emplace(const value_type&)
     Container c;
     const ValueTp v(42, 1);
     cc->expect<const ValueTp&>();
@@ -309,7 +307,7 @@ void testMapEmplace()
     }
   }
   {
-    CHECKPOINT("Testing C::emplace(value_type&)");
+    // Testing C::emplace(value_type&)
     Container c;
     ValueTp v(42, 1);
     cc->expect<ValueTp&>();
@@ -322,7 +320,7 @@ void testMapEmplace()
     }
   }
   {
-    CHECKPOINT("Testing C::emplace(value_type&&)");
+    // Testing C::emplace(value_type&&)
     Container c;
     ValueTp v(42, 1);
     cc->expect<ValueTp&&>();
@@ -335,7 +333,7 @@ void testMapEmplace()
     }
   }
   {
-    CHECKPOINT("Testing C::emplace(const value_type&&)");
+    // Testing C::emplace(const value_type&&)
     Container c;
     const ValueTp v(42, 1);
     cc->expect<const ValueTp&&>();
@@ -348,7 +346,7 @@ void testMapEmplace()
     }
   }
   {
-    CHECKPOINT("Testing C::emplace(pair<Key, Mapped> const&)");
+    // Testing C::emplace(pair<Key, Mapped> const&)
     Container c;
     const NonConstKeyPair v(42, 1);
     cc->expect<const NonConstKeyPair&>();
@@ -361,7 +359,7 @@ void testMapEmplace()
     }
   }
   {
-    CHECKPOINT("Testing C::emplace(pair<Key, Mapped> &&)");
+    // Testing C::emplace(pair<Key, Mapped> &&)
     Container c;
     NonConstKeyPair v(42, 1);
     cc->expect<NonConstKeyPair&&>();
@@ -374,7 +372,7 @@ void testMapEmplace()
     }
   }
   {
-    CHECKPOINT("Testing C::emplace(const Key&, ConvertibleToMapped&&)");
+    // Testing C::emplace(const Key&, ConvertibleToMapped&&)
     Container c;
     const Key k(42);
     cc->expect<Key const&, int&&>();
@@ -387,7 +385,7 @@ void testMapEmplace()
     }
   }
   {
-    CHECKPOINT("Testing C::emplace(Key&, Mapped&)");
+    // Testing C::emplace(Key&, Mapped&)
     Container c;
     Key k(42);
     Mapped m(1);
@@ -401,7 +399,7 @@ void testMapEmplace()
     }
   }
   {
-    CHECKPOINT("Testing C::emplace(Key&&, Mapped&&)");
+    // Testing C::emplace(Key&&, Mapped&&)
     Container c;
     Key k(42);
     Mapped m(1);
@@ -416,7 +414,7 @@ void testMapEmplace()
     }
   }
   {
-    CHECKPOINT("Testing C::emplace(ConvertibleToKey&&, ConvertibleToMapped&&)");
+    // Testing C::emplace(ConvertibleToKey&&, ConvertibleToMapped&&)
     Container c;
     cc->expect<int&&, int&&>();
     assert(c.emplace(42, 1).second);
@@ -444,7 +442,7 @@ void testMapEmplaceHint()
   ConstructController* cc = getConstructController();
   cc->reset();
   {
-    CHECKPOINT("Testing C::emplace_hint(p, const value_type&)");
+    // Testing C::emplace_hint(p, const value_type&)
     Container c;
     const ValueTp v(42, 1);
     cc->expect<const ValueTp&>();
@@ -461,7 +459,7 @@ void testMapEmplaceHint()
     }
   }
   {
-    CHECKPOINT("Testing C::emplace_hint(p, value_type&)");
+    // Testing C::emplace_hint(p, value_type&)
     Container c;
     ValueTp v(42, 1);
     cc->expect<ValueTp&>();
@@ -478,7 +476,7 @@ void testMapEmplaceHint()
     }
   }
   {
-    CHECKPOINT("Testing C::emplace_hint(p, value_type&&)");
+    // Testing C::emplace_hint(p, value_type&&)
     Container c;
     ValueTp v(42, 1);
     cc->expect<ValueTp&&>();
@@ -495,7 +493,7 @@ void testMapEmplaceHint()
     }
   }
   {
-    CHECKPOINT("Testing C::emplace_hint(p, const value_type&&)");
+    // Testing C::emplace_hint(p, const value_type&&)
     Container c;
     const ValueTp v(42, 1);
     cc->expect<const ValueTp&&>();
@@ -512,7 +510,7 @@ void testMapEmplaceHint()
     }
   }
   {
-    CHECKPOINT("Testing C::emplace_hint(p, pair<Key, Mapped> const&)");
+    // Testing C::emplace_hint(p, pair<Key, Mapped> const&)
     Container c;
     const NonConstKeyPair v(42, 1);
     cc->expect<const NonConstKeyPair&>();
@@ -529,7 +527,7 @@ void testMapEmplaceHint()
     }
   }
   {
-    CHECKPOINT("Testing C::emplace_hint(p, pair<Key, Mapped>&&)");
+    // Testing C::emplace_hint(p, pair<Key, Mapped>&&)
     Container c;
     NonConstKeyPair v(42, 1);
     cc->expect<NonConstKeyPair&&>();
@@ -546,7 +544,7 @@ void testMapEmplaceHint()
     }
   }
   {
-    CHECKPOINT("Testing C::emplace_hint(p, const Key&, ConvertibleToMapped&&)");
+    // Testing C::emplace_hint(p, const Key&, ConvertibleToMapped&&)
     Container c;
     const Key k(42);
     cc->expect<Key const&, int&&>();
@@ -563,7 +561,7 @@ void testMapEmplaceHint()
     }
   }
   {
-    CHECKPOINT("Testing C::emplace_hint(p, Key&, Mapped&)");
+    // Testing C::emplace_hint(p, Key&, Mapped&)
     Container c;
     Key k(42);
     Mapped m(1);
@@ -582,7 +580,7 @@ void testMapEmplaceHint()
     }
   }
   {
-    CHECKPOINT("Testing C::emplace_hint(p, Key&&, Mapped&&)");
+    // Testing C::emplace_hint(p, Key&&, Mapped&&)
     Container c;
     Key k(42);
     Mapped m(1);
@@ -601,7 +599,7 @@ void testMapEmplaceHint()
     }
   }
   {
-    CHECKPOINT("Testing C::emplace_hint(p, ConvertibleToKey&&, ConvertibleToMapped&&)");
+    // Testing C::emplace_hint(p, ConvertibleToKey&&, ConvertibleToMapped&&)
     Container c;
     cc->expect<int&&, int&&>();
     It ret = c.emplace_hint(c.end(), 42, 1);
@@ -627,7 +625,7 @@ void testMultimapInsert()
   ConstructController* cc = getConstructController();
   cc->reset();
   {
-    CHECKPOINT("Testing C::insert(const value_type&)");
+    // Testing C::insert(const value_type&)
     Container c;
     const ValueTp v(42, 1);
     cc->expect<const ValueTp&>();
@@ -635,7 +633,7 @@ void testMultimapInsert()
     assert(!cc->unchecked());
   }
   {
-    CHECKPOINT("Testing C::insert(value_type&)");
+    // Testing C::insert(value_type&)
     Container c;
     ValueTp v(42, 1);
     cc->expect<ValueTp&>();
@@ -643,7 +641,7 @@ void testMultimapInsert()
     assert(!cc->unchecked());
   }
   {
-    CHECKPOINT("Testing C::insert(value_type&&)");
+    // Testing C::insert(value_type&&)
     Container c;
     ValueTp v(42, 1);
     cc->expect<ValueTp&&>();
@@ -651,14 +649,14 @@ void testMultimapInsert()
     assert(!cc->unchecked());
   }
   {
-    CHECKPOINT("Testing C::insert({key, value})");
+    // Testing C::insert({key, value})
     Container c;
     cc->expect<ValueTp&&>();
     c.insert({42, 1});
     assert(!cc->unchecked());
   }
   {
-    CHECKPOINT("Testing C::insert(std::initializer_list<ValueTp>)");
+    // Testing C::insert(std::initializer_list<ValueTp>)
     Container c;
     std::initializer_list<ValueTp> il = { ValueTp(1, 1), ValueTp(2, 1) };
     cc->expect<ValueTp const&>(2);
@@ -666,7 +664,7 @@ void testMultimapInsert()
     assert(!cc->unchecked());
   }
   {
-    CHECKPOINT("Testing C::insert(Iter, Iter) for *Iter = value_type const&");
+    // Testing C::insert(Iter, Iter) for *Iter = value_type const&
     Container c;
     const ValueTp ValueList[] = { ValueTp(1, 1), ValueTp(2, 1), ValueTp(3, 1) };
     cc->expect<ValueTp const&>(3);
@@ -674,7 +672,7 @@ void testMultimapInsert()
     assert(!cc->unchecked());
   }
   {
-    CHECKPOINT("Testing C::insert(Iter, Iter) for *Iter = value_type&&");
+    // Testing C::insert(Iter, Iter) for *Iter = value_type&&
     Container c;
     ValueTp ValueList[] = { ValueTp(1, 1), ValueTp(2, 1) , ValueTp(3, 1) };
     cc->expect<ValueTp&&>(3);
@@ -683,7 +681,7 @@ void testMultimapInsert()
     assert(!cc->unchecked());
   }
   {
-    CHECKPOINT("Testing C::insert(Iter, Iter) for *Iter = value_type&");
+    // Testing C::insert(Iter, Iter) for *Iter = value_type&
     Container c;
     ValueTp ValueList[] = { ValueTp(1, 1), ValueTp(2, 1) , ValueTp(3, 1) };
     cc->expect<ValueTp&>(3);
@@ -700,7 +698,7 @@ void testMultimapInsertHint()
   ConstructController* cc = getConstructController();
   cc->reset();
   {
-    CHECKPOINT("Testing C::insert(p, const value_type&)");
+    // Testing C::insert(p, const value_type&)
     Container c;
     const ValueTp v(42, 1);
     cc->expect<const ValueTp&>();
@@ -708,7 +706,7 @@ void testMultimapInsertHint()
     assert(!cc->unchecked());
   }
   {
-    CHECKPOINT("Testing C::insert(p, value_type&)");
+    // Testing C::insert(p, value_type&)
     Container c;
     ValueTp v(42, 1);
     cc->expect<ValueTp&>();
@@ -716,7 +714,7 @@ void testMultimapInsertHint()
     assert(!cc->unchecked());
   }
   {
-    CHECKPOINT("Testing C::insert(p, value_type&&)");
+    // Testing C::insert(p, value_type&&)
     Container c;
     ValueTp v(42, 1);
     cc->expect<ValueTp&&>();
@@ -724,7 +722,7 @@ void testMultimapInsertHint()
     assert(!cc->unchecked());
   }
   {
-    CHECKPOINT("Testing C::insert(p, {key, value})");
+    // Testing C::insert(p, {key, value})
     Container c;
     cc->expect<ValueTp&&>();
     c.insert(c.begin(), {42, 1});
