@@ -1,9 +1,8 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
@@ -14,6 +13,8 @@
 
 #include <list>
 
+#include "test_macros.h"
+
 struct A {
     std::list<A> l;
     std::list<A>::iterator it;
@@ -22,6 +23,8 @@ struct A {
     std::list<A>::const_reverse_iterator crit;
 };
 
-int main() {
+int main(int, char**) {
     A a;
+
+  return 0;
 }
