@@ -1,20 +1,21 @@
 
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
 // <unordered_map>
 
-// Check that std::unordered_multimap and it's iterators can be instantiated with an incomplete
+// Check that std::unordered_multimap and its iterators can be instantiated with an incomplete
 // type.
 
 #include <unordered_map>
 
+#include "test_macros.h"
+
 template <class Tp>
 struct MyHash {
   MyHash() {}
@@ -32,6 +33,8 @@ struct A {
 
 inline bool operator==(A const& L, A const& R) { return &L == &R; }
 
-int main() {
+int main(int, char**) {
     A a;
+
+  return 0;
 }
