@@ -1,17 +1,20 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
+// UNSUPPORTED: libcpp-has-no-localization
+
 // <locale.h>
 
 #include <locale.h>
 #include <type_traits>
 
+#include "test_macros.h"
+
 #ifndef LC_ALL
 #error LC_ALL not defined
 #endif
@@ -40,9 +43,11 @@
 #error NULL not defined
 #endif
 
-int main()
+int main(int, char**)
 {
-    lconv lc;
+    lconv lc; ((void)lc);
     static_assert((std::is_same<decltype(setlocale(0, "")), char*>::value), "");
     static_assert((std::is_same<decltype(localeconv()), lconv*>::value), "");
+
+    return 0;
 }
