@@ -1,13 +1,16 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
-// UNSUPPORTED: c++98, c++03, c++11, c++14
+// UNSUPPORTED: c++03, c++11, c++14
+// UNSUPPORTED: libcpp-has-no-filesystem-library
+
+// Filesystem is supported on Apple platforms starting with macosx10.15.
+// UNSUPPORTED: use_system_cxx_lib && target={{.+}}-apple-macosx10.{{9|10|11|12|13|14}}
 
 // <fstream>
 
@@ -16,11 +19,12 @@
 #include <fstream>
 #include <filesystem>
 #include <cassert>
+#include "test_macros.h"
 #include "platform_support.h"
 
 namespace fs = std::filesystem;
 
-int main() {
+int main(int, char**) {
 
   fs::path p = get_temp_file_name();
   {
@@ -37,7 +41,7 @@ int main() {
     assert(f.sbumpc() == '2');
     assert(f.sbumpc() == '3');
   }
-  std::remove(p.c_str());
+  std::remove(p.string().c_str());
   {
     std::wfilebuf f;
     assert(f.open(p, std::ios_base::out) != 0);
@@ -52,5 +56,7 @@ int main() {
     assert(f.sbumpc() == L'2');
     assert(f.sbumpc() == L'3');
   }
-  remove(p.c_str());
+  remove(p.string().c_str());
+
+  return 0;
 }
