@@ -1,13 +1,12 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
-// UNSUPPORTED: c++98, c++03
+// UNSUPPORTED: c++03
 
 // <initializer_list>
 
@@ -48,13 +47,15 @@ struct B
     }
 };
 
-#endif  // TEST_STD_VER > 11
+#endif // TEST_STD_VER > 11
 
-int main()
+int main(int, char**)
 {
-    A test1 = {3, 2, 1};
+    A test1 = {3, 2, 1}; (void)test1;
 #if TEST_STD_VER > 11
     constexpr B test2 = {3, 2, 1};
     (void)test2;
-#endif  // TEST_STD_VER > 11
+#endif // TEST_STD_VER > 11
+
+  return 0;
 }
