@@ -1,9 +1,8 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
@@ -15,6 +14,8 @@
 #include <cfloat>
 #include <cassert>
 
+#include "test_macros.h"
+
 template <class T>
 void
 test(T expected)
@@ -25,17 +26,20 @@ test(T expected)
     assert(std::numeric_limits<const volatile T>::round_error() == expected);
 }
 
-int main()
+int main(int, char**)
 {
     test<bool>(false);
     test<char>(0);
     test<signed char>(0);
     test<unsigned char>(0);
     test<wchar_t>(0);
+#if TEST_STD_VER > 17 && defined(__cpp_char8_t)
+    test<char8_t>(0);
+#endif
 #ifndef _LIBCPP_HAS_NO_UNICODE_CHARS
     test<char16_t>(0);
     test<char32_t>(0);
-#endif  // _LIBCPP_HAS_NO_UNICODE_CHARS
+#endif // _LIBCPP_HAS_NO_UNICODE_CHARS
     test<short>(0);
     test<unsigned short>(0);
     test<int>(0);
@@ -51,4 +55,6 @@ int main()
     test<float>(0.5);
     test<double>(0.5);
     test<long double>(0.5);
+
+  return 0;
 }
