@@ -1,12 +1,17 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
+// See bugs.llvm.org/PR20183
+//
+// XFAIL: use_system_cxx_lib && target={{.+}}-apple-macosx10.{{9|10|11}}
+
+// UNSUPPORTED: libcpp-has-no-random-device
+
 // <random>
 
 // class random_device;
@@ -15,10 +20,11 @@
 
 #include <random>
 #include <cassert>
+#include <system_error>
 
 #include "test_macros.h"
 
-int main()
+int main(int, char**)
 {
     {
         std::random_device r;
@@ -30,11 +36,13 @@ int main()
     try
     {
         std::random_device r("/dev/null");
-        r();
+        (void)r();
         LIBCPP_ASSERT(false);
     }
     catch (const std::system_error&)
     {
     }
 #endif
+
+  return 0;
 }
