@@ -1,9 +1,8 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 //
@@ -22,6 +21,8 @@
 #include <numeric>
 #include <cstddef>
 
+#include "test_macros.h"
+
 template <class T>
 inline
 T
@@ -30,11 +31,10 @@ sqr(T x)
     return x * x;
 }
 
-int main()
+int main(int, char**)
 {
     {
         typedef std::chi_squared_distribution<> D;
-        typedef D::param_type P;
         typedef std::minstd_rand G;
         G g;
         D d(0.5);
@@ -74,7 +74,6 @@ int main()
     }
     {
         typedef std::chi_squared_distribution<> D;
-        typedef D::param_type P;
         typedef std::minstd_rand G;
         G g;
         D d(1);
@@ -114,7 +113,6 @@ int main()
     }
     {
         typedef std::chi_squared_distribution<> D;
-        typedef D::param_type P;
         typedef std::mt19937 G;
         G g;
         D d(2);
@@ -152,4 +150,6 @@ int main()
         assert(std::abs((skew - x_skew) / x_skew) < 0.01);
         assert(std::abs((kurtosis - x_kurtosis) / x_kurtosis) < 0.01);
     }
+
+  return 0;
 }
