@@ -1,9 +1,8 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 //
@@ -20,6 +19,7 @@
 #include <thread>
 #include <cassert>
 
+#include "make_test_thread.h"
 #include "test_macros.h"
 
 typedef std::chrono::milliseconds ms;
@@ -66,7 +66,7 @@ void f3()
 #endif
 }
 
-#ifndef _LIBCPP_HAS_NO_VARIADICS
+#if TEST_STD_VER >= 11
 
 struct init1
 {
@@ -101,7 +101,7 @@ void f2()
     std::call_once(flg2, init2(), 4, 5);
 }
 
-#endif  // _LIBCPP_HAS_NO_VARIADICS
+#endif // TEST_STD_VER >= 11
 
 std::once_flag flg41;
 std::once_flag flg42;
@@ -135,7 +135,7 @@ void f42()
     std::call_once(flg41, init41);
 }
 
-#ifndef _LIBCPP_HAS_NO_VARIADICS
+#if TEST_STD_VER >= 11
 
 class MoveOnly
 {
@@ -174,7 +174,6 @@ public:
     void operator()(int&) {}
 };
 
-#if TEST_STD_VER >= 11
 // reference qualifiers on functions are a C++11 extension
 struct RefQual
 {
@@ -185,15 +184,15 @@ struct RefQual
     void operator()() & { ++lv_called; }
     void operator()() && { ++rv_called; }
 };
-#endif
-#endif
 
-int main()
+#endif // TEST_STD_VER >= 11
+
+int main(int, char**)
 {
     // check basic functionality
     {
-        std::thread t0(f0);
-        std::thread t1(f0);
+        std::thread t0 = support::make_test_thread(f0);
+        std::thread t1 = support::make_test_thread(f0);
         t0.join();
         t1.join();
         assert(init0_called == 1);
@@ -201,8 +200,8 @@ int main()
 #ifndef TEST_HAS_NO_EXCEPTIONS
     // check basic exception safety
     {
-        std::thread t0(f3);
-        std::thread t1(f3);
+        std::thread t0 = support::make_test_thread(f3);
+        std::thread t1 = support::make_test_thread(f3);
         t0.join();
         t1.join();
         assert(init3_called == 2);
@@ -211,26 +210,26 @@ int main()
 #endif
     // check deadlock avoidance
     {
-        std::thread t0(f41);
-        std::thread t1(f42);
+        std::thread t0 = support::make_test_thread(f41);
+        std::thread t1 = support::make_test_thread(f42);
         t0.join();
         t1.join();
         assert(init41_called == 1);
         assert(init42_called == 1);
     }
-#ifndef _LIBCPP_HAS_NO_VARIADICS
+#if TEST_STD_VER >= 11
     // check functors with 1 arg
     {
-        std::thread t0(f1);
-        std::thread t1(f1);
+        std::thread t0 = support::make_test_thread(f1);
+        std::thread t1 = support::make_test_thread(f1);
         t0.join();
         t1.join();
         assert(init1::called == 1);
     }
     // check functors with 2 args
     {
-        std::thread t0(f2);
-        std::thread t1(f2);
+        std::thread t0 = support::make_test_thread(f2);
+        std::thread t1 = support::make_test_thread(f2);
         t0.join();
         t1.join();
         assert(init2::called == 5);
@@ -245,7 +244,6 @@ int main()
         int i = 0;
         std::call_once(f, NonCopyable(), i);
     }
-#if TEST_STD_VER >= 11
 // reference qualifiers on functions are a C++11 extension
     {
         std::once_flag f1, f2;
@@ -255,6 +253,7 @@ int main()
         std::call_once(f2, std::move(rq));
         assert(rq.rv_called == 1);
     }
-#endif
-#endif  // _LIBCPP_HAS_NO_VARIADICS
+#endif // TEST_STD_VER >= 11
+
+  return 0;
 }
