@@ -1,14 +1,15 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
-// UNSUPPORTED: c++98, c++03
-//  Because we don't have a functioning decltype in C++03
+// Because we don't have a functioning decltype in C++03
+// UNSUPPORTED: c++03
+
+// UNSUPPORTED: libcpp-has-no-localization
 
 // <memory>
 
@@ -27,9 +28,11 @@
 #include "min_allocator.h"
 #include "deleter_types.h"
 
-int main()
+int main(int, char**)
 {
     std::unique_ptr<int, PointerDeleter<int>> p;
     std::ostringstream os;
     os << p; // expected-error {{invalid operands to binary expression}}
+
+  return 0;
 }
