@@ -1,9 +1,8 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
@@ -16,17 +15,17 @@
 
 #include "test_macros.h"
 
-int main()
+int main(int, char**)
 {
     typedef std::integral_constant<int, 5> _5;
     static_assert(_5::value == 5, "");
     static_assert((std::is_same<_5::value_type, int>::value), "");
     static_assert((std::is_same<_5::type, _5>::value), "");
-#ifndef _LIBCPP_HAS_NO_CONSTEXPR
+#if TEST_STD_VER >= 11
     static_assert((_5() == 5), "");
-#else
-    assert(_5() == 5);
 #endif
+    assert(_5() == 5);
+
 
 #if TEST_STD_VER > 11
     static_assert ( _5{}() == 5, "" );
@@ -48,4 +47,6 @@ int main()
     std::true_type t1;
     std::true_type t2 = t1;
     assert(t2);
+
+  return 0;
 }
